/******************************************************* 

		 eSAR Processor

   (Educational Synthetic Aperture Radar Processor)

		  developed by 
 
	    Department of Geophysics
	  Kangwon National Univeristy

 All right reserved by Kangwon National University.
 Contact: Dr. Hoonyol Lee (hoonyol@kangwon.ac.kr)

			* * *

The purpose of this educational SAR processor is to provide
some basic processing that is impractical for human calculation. 
This means that the user (mostly the student) should learn the meaning of
each SAR parameters and calculate them to be put into this eSAR processor.

This program requires the students:

   1) to provide the imput data as double, IQ in BIP,
   2) to provide all the information necessary from the header file,
   2) to calculate chrip parameters, 
   3) and to provide the Doppler paramters.

The students need to study the basic principles of SAR image formation,
and should be able to read, interpret, and derive the parameters
that is essential for SAR focusing and the following post-processing.     
The parameters need to be in the parameter file before running.
*************************************************************************/

#define VERSION "0.9" 
/************************************************************************
VERSION "0.9" (8 May 2004)
	1. all output in float, 
	2. raw data output added.
VERSION "0.8" (8 May 2004, INITIAL)
*************************************************************************/ 

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <string.h>

#include "para.h"
#include "ma.c"
#include "load_para.c"
#include "load_data.c"
#include "range_chirp.c"
#include "fft.c"
#include "range_matched_filter.c"
#include "range_migration.c"
#include "azimuth_chirp.c"
#include "azimuth_matched_filter.c"
#include "cfout.c"

void usage();
void intro();

main(int argc, char *argv[])
{
	intro();

	if(argc != 2){usage(); exit(0);} 

 
	/* Load Parameters and Data */
	printf("Load Parameters and Data\n"); 
	load_para(argv[1]);
	load_data();
	cfout(data, nazimuth_fft, nrange_fft, 1,0,0, "01_data_AP");


	/* Range Compression */
	printf("\nRange Compression\n");
	range_chirp();
	cfout(range_chirp_data, 1, nrange_fft, 0,0,0, "02_rchirp_IQ");	

	printf(" Forward FFT(range_chirp_data):\n");
	fft(range_chirp_data, 1, nrange_fft, 0, 1);
	cfout(range_chirp_data, 1, nrange_fft, 0,0,0, "03_rchirp_fft_IQ");	

	printf(" Forward FFT(data, range):\n");
	fft(data, nazimuth_fft, nrange_fft, 0, 1);
	cfout(data, nazimuth_fft, nrange_fft, 1,0,0, "04_data_rfft_AP");

	range_matched_filter();	
	cfout(data, nazimuth_fft, nrange_fft, 1,0,0, "05_rmfilter_AP");
	
	printf(" Inverse FFT(data, range):\n");
	fft(data, nazimuth_fft, nrange_fft, 0, -1);
	cfout(data, nazimuth_fft, nrange_fft, 1,0,0, "06_rcomp_AP");


	/* Range Migration */
	printf(" Range Migration\n");
	range_migration();
	cfout(data, nazimuth_fft, nrange_fft, 1,0,0, "07_rmigr_AP");


	/* Azimuth Compression */
	printf("\nAzimuth Compression\n");
	azimuth_chirp();
	cfout(azimuth_chirp_data, 1, nazimuth_fft, 0,0,0, "08_azchirp_IQ");

	printf(" Forward FFT(azimuth_chirp_data):\n");
	fft(azimuth_chirp_data, 1, nazimuth_fft, 0, 1);
	cfout(azimuth_chirp_data, 1, nazimuth_fft, 0,0,0, "09_azchirp_fft_IQ");
	
	printf(" Forward FFT(data, azimuth):\n");
	fft(data, nazimuth_fft, nrange_fft, 1, 1);
	cfout(data, nazimuth_fft, nrange_fft, 1,0,0, "10_data_azfft_AP");

	azimuth_matched_filter();
	cfout(data, nazimuth_fft, nrange_fft, 1,0,0, "11_azmfilter_AP");

	printf(" Inverse FFT(data, azimuth):\n");
	fft(data, nazimuth_fft, nrange_fft, 1, -1);
	cfout(data, nazimuth_fft, nrange_fft, 0, 0, 0, "slc_IQ");
	cfout(data, nazimuth_fft, nrange_fft, 1, 0, 0, "slc_AP");
}
 
void usage()
{
 	printf(" usage: esar parameter_file\n");

}

void intro()
{
printf("\n");
printf(" *************************************************** \n"); 
printf("*	           eSAR Processor                   *\n");
printf("*  (Educational Synthetic Aperture Radar Processor) *\n");
printf("* 		       v%s  			    *\n", VERSION);
printf("*     All right reserved by Dr. Hoonyol Lee,        *\n"); 
printf("* Dept. of Geophysics, Kangwon National University. *\n");
printf("* Email:hoonyol@kangwon.ac.kr, Tel:+82-33-250-8586  *\n");
printf(" *************************************************** \n"); 

}

   
