/*  load_para.c

	1. Load parameter files
	2. Derive relevant paramters
	2. Allocate memory
*/

void load_para(char *fname)
{

	FILE *fp;
	char vbuf[80];
	int malloc_total;

	printf("\n load_para:\n");	

	/* Input variables from the parameter file */
	if((fp=fopen(fname, "r")) == NULL)
	{
		printf("  (Error) Cannot open %s.\n\a", fname);
		exit(0);
	}

	printf("\n <Input Parameters>\n");

	fscanf(fp, "%s %s", vbuf, fhead);
	printf("  %s= %s\n", vbuf, fhead);

	fscanf(fp, "%s %d", vbuf, &nrange);
	printf("  %s= %d\n", vbuf, nrange);

	fscanf(fp, "%s %d", vbuf, &nazimuth);
	printf("  %s= %d\n", vbuf, nazimuth);

	fscanf(fp, "%s %d", vbuf, &nrange_fft);
	printf("  %s= %d\n", vbuf, nrange_fft);

	fscanf(fp, "%s %d", vbuf, &nazimuth_fft);
	printf("  %s= %d\n", vbuf, nazimuth_fft);

	fscanf(fp, "%s %lf", vbuf, &carrier_frequency);
	printf("  %s= %g Hz\n", vbuf, carrier_frequency);

	fscanf(fp, "%s %lf", vbuf, &chirp_rate);
	printf("  %s= %g Hz/s\n", vbuf, chirp_rate);

	fscanf(fp, "%s %lf", vbuf, &chirp_duration);
	printf("  %s= %g s\n", vbuf, chirp_duration);

	fscanf(fp, "%s %lf", vbuf, &range_sampling_frequency);
	printf("  %s= %g Hz\n", vbuf, range_sampling_frequency);

	fscanf(fp, "%s %lf", vbuf, &pulse_repetition_frequency);
	printf("  %s= %g Hz\n", vbuf, pulse_repetition_frequency);

	fscanf(fp, "%s %lf", vbuf, &nominal_mean_I);
	printf("  %s= %g\n", vbuf, nominal_mean_I);

	fscanf(fp, "%s %lf", vbuf, &nominal_mean_Q);
	printf("  %s= %g\n", vbuf, nominal_mean_Q);

	fscanf(fp, "%s %lf", vbuf, &DC_bias_I);
	printf("  %s= %g\n", vbuf, DC_bias_I);

	fscanf(fp, "%s %lf", vbuf, &DC_bias_Q);
	printf("  %s= %g\n", vbuf, DC_bias_Q);

	fscanf(fp, "%s %lf", vbuf, &range_first_time);
	printf("  %s= %g s\n", vbuf, range_first_time);

	fscanf(fp, "%s %lf", vbuf, &range_centre_time);
	printf("  %s= %g s\n", vbuf, range_centre_time);

	fscanf(fp, "%s %lf", vbuf, &range_last_time);
	printf("  %s= %g s\n", vbuf, range_last_time);

	fscanf(fp, "%s %lf", vbuf, &satellite_velocity);
	printf("  %s= %g m/s\n", vbuf, satellite_velocity);
	
	fscanf(fp, "%s %lf", vbuf, &satellite_squint_radian);
	printf("  %s= %g\n", vbuf, satellite_squint_radian);
	
	fscanf(fp, "%s %lf", vbuf, &antenna_azimuth_length);
	printf("  %s= %g m\n", vbuf, antenna_azimuth_length);
	
	fscanf(fp, "%s %lf", vbuf, &nominal_incidence_degree);
	printf("  %s= %g m\n", vbuf, nominal_incidence_degree);
	
	fclose(fp);

  	/* Generic Parameters */
	cspeed=2.997925e8;
	pi = 4.*atan(1.); 	

	printf("\n <Generic Parameters>\n");
	printf("  cspeed= %g m/s\n", cspeed);
	printf("  pi= %g\n", pi);

	/* Induced Parameters */
	delta_t= 1./range_sampling_frequency;
	delta_s= 1./pulse_repetition_frequency;	
	wavelength= cspeed/carrier_frequency;

	range_pixel_size=cspeed*delta_t/2.;
	azimuth_pixel_size=satellite_velocity*delta_s;
	
	range_first= range_first_time*cspeed/2.;
	range_centre= range_centre_time*cspeed/2.;
	range_last= range_last_time*cspeed/2.;

	Doppler_centroid= 2.*satellite_velocity/wavelength 
			    *sin(satellite_squint_radian);

	Doppler_rate= (-2.)/wavelength/range_centre 
			    *satellite_velocity
			    *satellite_velocity;

	coherent_integration_time= wavelength*range_centre/
		(satellite_velocity*antenna_azimuth_length);

	range_bandwidth=fabs(chirp_rate)*chirp_duration;
	range_time_resolution=1./range_bandwidth;
	slant_range_resolution=cspeed*range_time_resolution/2.;
	nominal_incidence_radian=nominal_incidence_degree*pi/180.;
	ground_range_resolution=slant_range_resolution/
		nominal_incidence_radian;
 	range_compression_ratio=range_bandwidth*chirp_duration;
	
	azimuth_bandwidth=fabs(Doppler_rate)*coherent_integration_time;
	azimuth_time_resolution=1./azimuth_bandwidth;
	azimuth_resolution=satellite_velocity*azimuth_time_resolution;
	azimuth_compression_ratio=azimuth_bandwidth*coherent_integration_time;	
		
	printf("\n <Induced Parameters>\n");
	printf("  delta_t= %e s\n", delta_t);
	printf("  delta_s= %e s\n", delta_s);
	printf("  wavelength= %g m\n", wavelength);
	printf("  range_first= %g m\n", range_first);
	printf("  range_centre= %g m\n", range_centre);
	printf("  range_last= %g m\n", range_last);
	printf("  Doppler_centroid= %g Hz\n", Doppler_centroid);
	printf("  Doppler_rate= %g Hz/s\n", Doppler_rate);
	printf("  coherent_integration_time= %g s\n", coherent_integration_time);
	printf("  range_pixel_size= %g m\n", range_pixel_size);
	printf("  azimuth_pixel_size= %g m\n", azimuth_pixel_size);
	printf("  range_bandwidth= %g Hz\n", range_bandwidth);
	printf("  azimuth_bandwidth= %g Hz\n", azimuth_bandwidth);
	printf("  range_time_resolution= %g s\n", range_time_resolution);
	printf("  azimuth_time_resolution= %g s\n", azimuth_time_resolution);
	printf("  slant_range_resolution= %g m\n", slant_range_resolution);
	printf("  ground_range_resolution= %g m\n", ground_range_resolution); 
	printf("  azimuth_resolution= %g m\n", azimuth_resolution);
	printf("  range_compression_ratio= %g\n", range_compression_ratio);	
	printf("  azimuth_compression_ratio= %g\n", azimuth_compression_ratio);	

	/* allocate memory */
	malloc_total=0;

	data = dvector(nrange_fft*nazimuth_fft*2); 
	malloc_total += nrange_fft*nazimuth_fft*2;

	printf("\n  Total memory allocated: %d bytes.\n", malloc_total);

}



	
